4.3.0 (2023-11-23)
==================
🎉 New features
--------------

- add a method to InstanceCommand to have a connexion
- add a warning message when running the instance with the default session (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/801)
- config: add sender-x-cw-header entry
- schema: type `CubicWebSchema.add_entity_type` (to https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/775)
- security: allow to disable default protection against CSRF attack in pyramid.ini (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/904)
- skeleton: add new 'web' layout that insert cubicweb-web dependency with its version
- skeleton: max cubicweb version of new cubes to the next major
- skeleton: only add web tests when using the web layout

👷 Bug fixes
-----------

- content_negociation: if we only want rdf views, don't catch all mimetypes (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/906)
- make doc build compatible with sphinx_book_theme version 1.*
- setup.py: switch to Environment markers for conditionnal installations
- slapd: back_hdb and back_bdb are deprecated in favor of back_mdp
- tests: make slapd log its error messages on stdout for debug purpose
- tests: make tests crash if slapd fails to initialize its database

📝 Documentation
---------------

- csrf: fix the wrong code for “Disable CSRF for a CubicWeb View” chapter

🤖 Continuous integration
------------------------

- feat: allow to select what job to launch using labels
- refactor: make python-logilab:latest the default image
- skeleton: test web layout
- typo in bash that could break a condition if a variable is missing

🤷 Various changes
-----------------

- contributing: add CONTRIBUTING.rst file
- contributing: remove outdated guides
- contributing: update weekly meeting description
- cw4: add a missing topic about translations in migration to CW4 documentation (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/840)
- cw4: add missing part about RecipientFinders in migration documentation (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/804)
- fix title length to please sphinx
- paginated_rset has been moved to cubicweb_web
- remove a file related to a removed module
- remove reference to a missing image in a documentation we don't maintain anymore
- remove reference to a removed file
- remove reference to an unexisting file
- sphinx dislike ~ for a subsubsection
- still build cubicweb.web documentation
- stuff have been moved to bwcompat
- view module has been moved to cubicweb_web
- WARNING: Bullet list ends without a blank line; unexpected unindent.